==> Acme-MetaSyntactic-Themes-1.045.tar.gz: Acme-MetaSyntactic-Themes-1.045/lib/Acme/MetaSyntactic/discworld.pm <==
package Acme::MetaSyntactic::discworld;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::discworld - The Discworld theme

=head1 DESCRIPTION

This theme contains items from Terry Pratchett's Discworld series.

=head1 CONTRIBUTORS

Martin Vorlnder, Jean Forget.

=head1 CHANGES

=over 4

=item *

2012-05-14 - v1.001

Updated with an C<=encoding> pod command.

Published in Acme-MetaSyntactic-Themes version 1.001.

=item *

2012-05-07

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-11-07

Updated by Jean Forget in Acme-MetaSyntactic version 0.47.

=item *

2005-10-03

Introduced in Acme-MetaSyntactic version 0.42.

=item *

2005-09-02

Initial list proposed by Martin Vorlnder.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
great_a_tuin berilia jerakeen tubul great_t_phon
rincewind twoflower death nanny_ogg granny_weatherwax magrat_garlick
agnes_nitt king_verence jason_ogg shawn_ogg
mustrum_ridcully ponder_stibbons windle_poons ipslore igneous_cutwell
eric mort ysabell susan binky
alberto_malich lord_vetinari leonardo_da_quirm lady_sybil_ramkin
greebo pteppic ptraci 
captain_vimes carrot angua littlebottom
detritus sergeant_colon nobby reg_shoe errol gaspode bel_shamharoth
offler blind_io creosote conina nijel koomi ksandra granpone bravd weasel tethis
bathys garhartra dibbler gaffer silverfish
brutha vorbis casanunda william_de_worde
cohen caleb_the_ripper old_vincent mad_hamish boy_willy

ankh_morpork the_broken_drum dunmanifestin wyrmberg nef sto_lat lancre
cori_celesti tsort pseudopolis sto_helit klatch quirm
ramtops uberwald djelibeybi ephebe genua llamedos agatean_empire xxxx

==> Acme-MetaSyntactic-Themes-1.054.tar.gz: Acme-MetaSyntactic-Themes-1.054/lib/Acme/MetaSyntactic/discworld.pm <==
package Acme::MetaSyntactic::discworld;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.002';
__PACKAGE__->init();
'7a';

=encoding utf-8

=head1 NAME

Acme::MetaSyntactic::discworld - The Discworld theme

=head1 DESCRIPTION

This theme contains items from Terry Pratchett's Discworld series.

=head1 CONTRIBUTORS

Martin Vorländer, Jean Forget.

=head1 IN MEMORIAM

This theme is dedicated to

=over 4

=item Josh Kirby (1928-2001)

"I only invented the Discworld. Josh created it."

-- Terry Pratchett

=item Terry Pratchett (1948-2015)

  AT LAST, SIR TERRY, WE MUST WALK TOGETHER.

  Terry took Death’s arm and followed him through the doors and on to the black desert under the endless night.

  The End

  @terryandrob on Twitter, 12 March 2015

=back

=head1 CHANGES

=over 4

=item *

2015-06-08 - v1.002

Updated with L<IN MEMORIAM> after the passing of Sir Terry Pratchett
on March 12, 2015. Published in Acme-MetaSyntactic-Themes version 1.046.

=item *

2012-05-14 - v1.001

Updated with an C<=encoding> pod command.

Published in Acme-MetaSyntactic-Themes version 1.001.

=item *

2012-05-07

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-11-07

Updated by Jean Forget in Acme-MetaSyntactic version 0.47.

=item *

2005-10-03

Introduced in Acme-MetaSyntactic version 0.42.

=item *

2005-09-02

Initial list proposed by Martin Vorländer.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
great_a_tuin berilia jerakeen tubul great_t_phon
rincewind twoflower death nanny_ogg granny_weatherwax magrat_garlick
agnes_nitt king_verence jason_ogg shawn_ogg
mustrum_ridcully ponder_stibbons windle_poons ipslore igneous_cutwell
eric mort ysabell susan binky
alberto_malich lord_vetinari leonardo_da_quirm lady_sybil_ramkin
greebo pteppic ptraci 
captain_vimes carrot angua littlebottom
detritus sergeant_colon nobby reg_shoe errol gaspode bel_shamharoth
offler blind_io creosote conina nijel koomi ksandra granpone bravd weasel tethis
bathys garhartra dibbler gaffer silverfish
brutha vorbis casanunda william_de_worde
cohen caleb_the_ripper old_vincent mad_hamish boy_willy

ankh_morpork the_broken_drum dunmanifestin wyrmberg nef sto_lat lancre
cori_celesti tsort pseudopolis sto_helit klatch quirm
ramtops uberwald djelibeybi ephebe genua llamedos agatean_empire xxxx
